########################################################################
# 
# @(#) ericsson-utran/p5_perf/DDM_MANIP_Config.pm ericsson-utran_d3.3.1.latest:cset.003128:3:3@(#)
#-------------------------------------------------------------------------------
#
# This perl module contains the configuration information for this parser.
# If you don't understand the format of this configuration file DON'T TOUCH IT.
#
# Description : This module contains configuration for the manipulation of
# DDM (Discrete Distributed Measurement) Note this default configuration is
# empty, so no measurement types will be manipulated.
# See the examples in example/ddm_manip for more information
#
# (c) Copyright IBM Corporation, 2007. All rights reserved.
#
#########################################################################
#
# Ericsson UTRAN P5 - Performance data
# This configuration contains configurations for Ericsson UTRAN performance 
# counters requiring processing by the Discrete Distributed Measurement (DDM)
# engine
# 
package DDM_MANIP_Config;

@ISA    = qw(Exporter) ;
@EXPORT = qw(ddm_manip_config) ;

use strict ;
use Exporter ();

my %DDM_MANIP_RULES =
    (
     # values to be ignored
     INVALID_VALUES => ['-1'],
     # replace the invalid values with
     MISSING_VALUE  => '0',
     # the number of digits to use in the precision for
     # output of averages etc. 
     # precision of 2 => DD.PP (2 digits to RHS of point)
     PRECISION      => '2',
     COUNTERS_TO_MANIP =>
     {
	 # ManagedElement,RncFunction,IubLink,IubEdch
	 # Constant interval, increment by 10 starting from 0
         pmEdchDataFrameDelayIub => [
            { MANIP_TYPE  => 'WEIGHTED_AVG',
              RANGE_INDEX => [
                  { START_INDEX => '0',
                    END_INDEX   => '15',
                    WEIGHTED_START => '10',
                    WEIGHTED_STEP => '+10',
                    OUTPUT_COUNTER_NAME => 'pmEdchDataFrameDelayIub_Avg',
                  },
              ],
            },
            { MANIP_TYPE  => 'REFERENCE',
              RANGE_INDEX => [
                  { START_INDEX => '0',
                    END_INDEX   => '15',
                    REFERENCE_TYPE => 'FIRST',
                    REFERENCE_START => '10',
                    REFERENCE_STEP => '+10',
                    OUTPUT_COUNTER_NAME => 'pmEdchDataFrameDelayIub_Min',
                  },
                  { START_INDEX => '0',
                    END_INDEX   => '15',
                    REFERENCE_TYPE => 'LAST',
                    REFERENCE_START => '10',
                    REFERENCE_STEP => '+10',
                    OUTPUT_COUNTER_NAME => 'pmEdchDataFrameDelayIub_Max',
                  },
              ],
            },
         ],
	 # ManagedElement,RncFunction,UtranCell
         pmDlRlcUserPacketThp => [
            { MANIP_TYPE  => 'WEIGHTED_AVG',
              RANGE_INDEX => [
                  { START_INDEX => '0',
                    END_INDEX   => '40',
                    WEIGHTED_ARRAY => [
		    	2.5, 12.5, 30, 50, 70, 90, 110, 130,
		    	150, 170, 190, 210, 230, 250, 270, 290,
		    	310, 330, 350, 370, 390, 450, 550, 650, 750,
		    	850, 950, 1125, 1375, 1625, 1875, 2250, 2750, 3500,
		    	4500, 5500, 6500, 7500, 9000, 11000, 13000 
		    ],
                    OUTPUT_COUNTER_NAME => 'pmDlRlcUserPacketThp_Avg',
                  },
              ],
            },
            { MANIP_TYPE  => 'REFERENCE',
              RANGE_INDEX => [
                  { START_INDEX => '0',
                    END_INDEX   => '40',
                    REFERENCE_ARRAY => [
		    	2.5, 12.5, 30, 50, 70, 90, 110, 130,
		    	150, 170, 190, 210, 230, 250, 270, 290,
		    	310, 330, 350, 370, 390, 450, 550, 650, 750,
		    	850, 950, 1125, 1375, 1625, 1875, 2250, 2750, 3500,
		    	4500, 5500, 6500, 7500, 9000, 11000, 13000 
		    ],
                    REFERENCE_TYPE => 'FIRST',
                    OUTPUT_COUNTER_NAME => 'pmDlRlcUserPacketThp_Min',
                  },
                  { START_INDEX => '0',
                    END_INDEX   => '40',
                    REFERENCE_ARRAY => [
		    	2.5, 12.5, 30, 50, 70, 90, 110, 130,
		    	150, 170, 190, 210, 230, 250, 270, 290,
		    	310, 330, 350, 370, 390, 450, 550, 650, 750,
		    	850, 950, 1125, 1375, 1625, 1875, 2250, 2750, 3500,
		    	4500, 5500, 6500, 7500, 9000, 11000, 13000 
		    ],
                    REFERENCE_TYPE => 'LAST',
                    OUTPUT_COUNTER_NAME => 'pmDlRlcUserPacketThp_Max',
                  },
              ],
            },
         ],
         pmUlRlcUserPacketThp => [
            { MANIP_TYPE  => 'WEIGHTED_AVG',
              RANGE_INDEX => [
                  { START_INDEX => '0',
                    END_INDEX   => '29',
                    WEIGHTED_ARRAY => [
		    	2.5, 12.5, 30, 50, 70, 90, 110, 130, 
			150, 170, 190, 210, 230, 250, 270, 290, 
			310, 330, 350, 370, 390, 450, 550, 650, 
			750, 850, 950, 1125, 1375, 1625
		    ],
                    OUTPUT_COUNTER_NAME => 'pmUlRlcUserPacketThp_Avg',
                  },
              ],
            },
            { MANIP_TYPE  => 'REFERENCE',
              RANGE_INDEX => [
                  { START_INDEX => '0',
                    END_INDEX   => '29',
                    REFERENCE_ARRAY => [
		    	2.5, 12.5, 30, 50, 70, 90, 110, 130, 
			150, 170, 190, 210, 230, 250, 270, 290, 
			310, 330, 350, 370, 390, 450, 550, 650, 
			750, 850, 950, 1125, 1375, 1625
		    ],
                    REFERENCE_TYPE => 'FIRST',
                    OUTPUT_COUNTER_NAME => 'pmUlRlcUserPacketThp_Min',
                  },
                  { START_INDEX => '0',
                    END_INDEX   => '29',
                    REFERENCE_ARRAY => [
		    	2.5, 12.5, 30, 50, 70, 90, 110, 130, 
			150, 170, 190, 210, 230, 250, 270, 290, 
			310, 330, 350, 370, 390, 450, 550, 650, 
			750, 850, 950, 1125, 1375, 1625
		    ],
                    REFERENCE_TYPE => 'LAST',
                    OUTPUT_COUNTER_NAME => 'pmUlRlcUserPacketThp_Max',
                  },
              ],
            },
         ],
         pmEulHarqTransmTti10PsInteractive => [
            { MANIP_TYPE  => 'WEIGHTED_AVG',
              RANGE_INDEX => [
                  { START_INDEX => '0',
                    END_INDEX   => '3',
                    WEIGHTED_START => '1',
                    WEIGHTED_STEP => '+1',
                    OUTPUT_COUNTER_NAME => 'pmEulHarqTransmTti10PsInteractive_Avg',
                  },
              ],
            },
            { MANIP_TYPE  => 'REFERENCE',
              RANGE_INDEX => [
                  { START_INDEX => '0',
                    END_INDEX   => '3',
                    REFERENCE_TYPE => 'FIRST',
                    REFERENCE_START => '1',
                    REFERENCE_STEP => '+1',
                    OUTPUT_COUNTER_NAME => 'pmEulHarqTransmTti10PsInteractive_Min',
                  },
                  { START_INDEX => '0',
                    END_INDEX   => '3',
                    REFERENCE_TYPE => 'LAST',
                    REFERENCE_START => '1',
                    REFERENCE_STEP => '+1',
                    OUTPUT_COUNTER_NAME => 'pmEulHarqTransmTti10PsInteractive_Max',
                  },
              ],
            },
         ],
         pmEulHarqTransmTti10Srb  => [
            { MANIP_TYPE  => 'WEIGHTED_AVG',
              RANGE_INDEX => [
                  { START_INDEX => '0',
                    END_INDEX   => '3',
                    WEIGHTED_START => '1',
                    WEIGHTED_STEP => '+1',
                    OUTPUT_COUNTER_NAME => 'pmEulHarqTransmTti10Srb_Avg',
                  },
              ],
            },
            { MANIP_TYPE  => 'REFERENCE',
              RANGE_INDEX => [
                  { START_INDEX => '0',
                    END_INDEX   => '3',
                    REFERENCE_TYPE => 'FIRST',
                    REFERENCE_START => '1',
                    REFERENCE_STEP => '+1',
                    OUTPUT_COUNTER_NAME => 'pmEulHarqTransmTti10Srb_Min',
                  },
                  { START_INDEX => '0',
                    END_INDEX   => '3',
                    REFERENCE_TYPE => 'LAST',
                    REFERENCE_START => '1',
                    REFERENCE_STEP => '+1',
                    OUTPUT_COUNTER_NAME => 'pmEulHarqTransmTti10Srb_Max',
                  },
              ],
            },
         ],
	 # ManagedElement,NodeBFunction,Sector,Carrier,EDchResources
         pmNoiseFloor => [
            { MANIP_TYPE  => 'WEIGHTED_AVG',
              RANGE_INDEX => [
                  { START_INDEX => '0',
                    END_INDEX   => '55',
		    AVG_TYPE => 'dBm',
                    WEIGHTED_ARRAY => [
			-114, -113.5, -112.5, -111.5, -110.5, -109.5, -108.5, -107.5, 
			-106.5, -105.5, -104.5, -103.5, -102.5, -101.5, -100.5, -99.5, 
			-98.5, -97.5, -96.5, -95.5, -94.5, -93.5, -92.5, -91.5, 
			-90.5, -89.5, -88.5, -87.5, -86.5, -85.5, -84.5, -83.5, 
			-82.5, -81.5, -80.5, -79.5, -78.5, -77.5, -76.5, -75.5, 
			-74.5, -73.5, -72.5, -71.5, -70.5, -69.5, -68.5, -67.5, 
			-66.5, -65.5, -64.5, -63.5, -62.5, -61.5, -60.5, -59.5 
		    ],
                    OUTPUT_COUNTER_NAME => 'pmNoiseFloor_Avg',
                  },
              ],
            },
            { MANIP_TYPE  => 'REFERENCE',
              RANGE_INDEX => [
                  { START_INDEX => '0',
                    END_INDEX   => '55',
                    REFERENCE_ARRAY => [
			-114, -113.5, -112.5, -111.5, -110.5, -109.5, -108.5, -107.5, 
			-106.5, -105.5, -104.5, -103.5, -102.5, -101.5, -100.5, -99.5, 
			-98.5, -97.5, -96.5, -95.5, -94.5, -93.5, -92.5, -91.5, 
			-90.5, -89.5, -88.5, -87.5, -86.5, -85.5, -84.5, -83.5, 
			-82.5, -81.5, -80.5, -79.5, -78.5, -77.5, -76.5, -75.5, 
			-74.5, -73.5, -72.5, -71.5, -70.5, -69.5, -68.5, -67.5, 
			-66.5, -65.5, -64.5, -63.5, -62.5, -61.5, -60.5, -59.5 
		    ],
                    REFERENCE_TYPE => 'FIRST',
                    OUTPUT_COUNTER_NAME => 'pmNoiseFloor_Min',
                  },
                  { START_INDEX => '0',
                    END_INDEX   => '55',
                    REFERENCE_ARRAY => [
			-114, -113.5, -112.5, -111.5, -110.5, -109.5, -108.5, -107.5, 
			-106.5, -105.5, -104.5, -103.5, -102.5, -101.5, -100.5, -99.5, 
			-98.5, -97.5, -96.5, -95.5, -94.5, -93.5, -92.5, -91.5, 
			-90.5, -89.5, -88.5, -87.5, -86.5, -85.5, -84.5, -83.5, 
			-82.5, -81.5, -80.5, -79.5, -78.5, -77.5, -76.5, -75.5, 
			-74.5, -73.5, -72.5, -71.5, -70.5, -69.5, -68.5, -67.5, 
			-66.5, -65.5, -64.5, -63.5, -62.5, -61.5, -60.5, -59.5 
		    ],
                    REFERENCE_TYPE => 'LAST',
                    OUTPUT_COUNTER_NAME => 'pmNoiseFloor_Max',
                  },
              ],
            },
         ],
         pmCommonChPowerEul  => [
            { MANIP_TYPE  => 'WEIGHTED_AVG',
              RANGE_INDEX => [
                  { START_INDEX => '0',
                    END_INDEX   => '40',
		    AVG_TYPE => 'dBm',
                    WEIGHTED_START => '0.5',
                    WEIGHTED_STEP => '+1',
                    OUTPUT_COUNTER_NAME => 'pmCommonChPowerEul_Avg',
                  },
              ],
            },
            { MANIP_TYPE  => 'REFERENCE',
              RANGE_INDEX => [
                  { START_INDEX => '0',
                    END_INDEX   => '40',
                    REFERENCE_TYPE => 'FIRST',
                    REFERENCE_START => '0.5',
                    REFERENCE_STEP => '+1',
                    OUTPUT_COUNTER_NAME => 'pmCommonChPowerEul_Min',
                  },
                  { START_INDEX => '0',
                    END_INDEX   => '40',
                    REFERENCE_TYPE => 'LAST',
                    REFERENCE_START => '0.5',
                    REFERENCE_STEP => '+1',
                    OUTPUT_COUNTER_NAME => 'pmCommonChPowerEul_Max',
                  },
              ],
            },
         ],
         pmNoSchEdchEul => [
            { MANIP_TYPE  => 'WEIGHTED_AVG',
              RANGE_INDEX => [
                  { START_INDEX => '0',
                    END_INDEX   => '20',
                    WEIGHTED_ARRAY => [
		    	0.5, 1.5, 2.5, 3.5, 4.5, 5.5, 6.5, 7.5, 
			8.5, 9.5, 12.5, 17.5, 22.5, 27.5, 35, 45, 
			55, 65, 75, 85, 95 
		    ],
                    OUTPUT_COUNTER_NAME => 'pmNoSchEdchEul_Avg',
                  },
              ],
            },
            { MANIP_TYPE  => 'REFERENCE',
              RANGE_INDEX => [
                  { START_INDEX => '0',
                    END_INDEX   => '20',
                    REFERENCE_ARRAY => [
		    	0.5, 1.5, 2.5, 3.5, 4.5, 5.5, 6.5, 7.5, 
			8.5, 9.5, 12.5, 17.5, 22.5, 27.5, 35, 45, 
			55, 65, 75, 85, 95 
		    ],
                    REFERENCE_TYPE => 'FIRST',
                    OUTPUT_COUNTER_NAME => 'pmNoSchEdchEul_Min',
                  },
                  { START_INDEX => '0',
                    END_INDEX   => '20',
                    REFERENCE_ARRAY => [
		    	0.5, 1.5, 2.5, 3.5, 4.5, 5.5, 6.5, 7.5, 
			8.5, 9.5, 12.5, 17.5, 22.5, 27.5, 35, 45, 
			55, 65, 75, 85, 95 
		    ],
                    REFERENCE_TYPE => 'LAST',
                    OUTPUT_COUNTER_NAME => 'pmNoSchEdchEul_Max',
                  },
              ],
            },
         ],
         pmOwnUuLoad  => [
            { MANIP_TYPE  => 'WEIGHTED_AVG',
              RANGE_INDEX => [
                  { START_INDEX => '0',
                    END_INDEX   => '50',
                    WEIGHTED_START => '0.1',
                    WEIGHTED_STEP => '+0.2',
		    AVG_TYPE => 'dB',
                    OUTPUT_COUNTER_NAME => 'pmOwnUuLoad_Avg',
                  },
              ],
            },
            { MANIP_TYPE  => 'REFERENCE',
              RANGE_INDEX => [
                  { START_INDEX => '0',
                    END_INDEX   => '50',
                    REFERENCE_TYPE => 'FIRST',
                    REFERENCE_START => '0.1',
                    REFERENCE_STEP => '+0.2',
                    OUTPUT_COUNTER_NAME => 'pmOwnUuLoad_Min',
                  },
                  { START_INDEX => '0',
                    END_INDEX   => '50',
                    REFERENCE_TYPE => 'LAST',
                    REFERENCE_START => '0.1',
                    REFERENCE_STEP => '+0.2',
                    OUTPUT_COUNTER_NAME => 'pmOwnUuLoad_Max',
                  },
              ],
            },
     	 ],
         pmTotalRotCoverage  => [
            { MANIP_TYPE  => 'WEIGHTED_AVG',
              RANGE_INDEX => [
                  { START_INDEX => '0',
                    END_INDEX   => '50',
		    AVG_TYPE => 'dB',
                    WEIGHTED_ARRAY => [
		    	0.5, 0.75, 1.25, 1.75, 2.25, 2.75, 3.25, 3.75, 
		    	4.25, 4.75, 5.25, 5.75, 6.25, 6.75, 7.25, 7.75, 
		    	8.25, 8.75, 9.25, 9.75, 10.25, 10.75, 11.25, 11.75, 
		    	12.25, 12.75, 13.25, 13.75, 14.25, 14.75, 15.25, 15.75, 
		    	16.25, 16.75, 17.25, 17.75, 18.25, 18.75, 19.25, 19.75, 
		    	20.25, 20.75, 21.25, 21.75, 22.25, 22.75, 23.25, 23.75, 
		    	24.25, 24.75, 25.25 
		    ],
                    OUTPUT_COUNTER_NAME => 'pmTotalRotCoverage_Avg',
                  },
              ],
            },
            { MANIP_TYPE  => 'REFERENCE',
              RANGE_INDEX => [
                  { START_INDEX => '0',
                    END_INDEX   => '50',
                    REFERENCE_TYPE => 'FIRST',
                    REFERENCE_ARRAY => [
		    	0.5, 0.75, 1.25, 1.75, 2.25, 2.75, 3.25, 3.75, 
		    	4.25, 4.75, 5.25, 5.75, 6.25, 6.75, 7.25, 7.75, 
		    	8.25, 8.75, 9.25, 9.75, 10.25, 10.75, 11.25, 11.75, 
		    	12.25, 12.75, 13.25, 13.75, 14.25, 14.75, 15.25, 15.75, 
		    	16.25, 16.75, 17.25, 17.75, 18.25, 18.75, 19.25, 19.75, 
		    	20.25, 20.75, 21.25, 21.75, 22.25, 22.75, 23.25, 23.75, 
		    	24.25, 24.75, 25.25 
		    ],
                    OUTPUT_COUNTER_NAME => 'pmTotalRotCoverage_Min',
                  },
                  { START_INDEX => '0',
                    END_INDEX   => '50',
                    REFERENCE_TYPE => 'LAST',
                    REFERENCE_ARRAY => [
		    	0.5, 0.75, 1.25, 1.75, 2.25, 2.75, 3.25, 3.75, 
		    	4.25, 4.75, 5.25, 5.75, 6.25, 6.75, 7.25, 7.75, 
		    	8.25, 8.75, 9.25, 9.75, 10.25, 10.75, 11.25, 11.75, 
		    	12.25, 12.75, 13.25, 13.75, 14.25, 14.75, 15.25, 15.75, 
		    	16.25, 16.75, 17.25, 17.75, 18.25, 18.75, 19.25, 19.75, 
		    	20.25, 20.75, 21.25, 21.75, 22.25, 22.75, 23.25, 23.75, 
		    	24.25, 24.75, 25.25 
		    ],
                    OUTPUT_COUNTER_NAME => 'pmTotalRotCoverage_Max',
                  },
              ],
            },
     	 ],
         pmTotRateGrantedEul  => [
            { MANIP_TYPE  => 'WEIGHTED_AVG',
              RANGE_INDEX => [
                  { START_INDEX => '0',
                    END_INDEX   => '60',
                    WEIGHTED_START => '100',
                    WEIGHTED_STEP => '+100',
                    OUTPUT_COUNTER_NAME => 'pmTotRateGrantedEul_Avg',
                  },
              ],
            },
            { MANIP_TYPE  => 'REFERENCE',
              RANGE_INDEX => [
                  { START_INDEX => '0',
                    END_INDEX   => '60',
                    REFERENCE_TYPE => 'FIRST',
                    REFERENCE_START => '100',
                    REFERENCE_STEP => '+100',
                    OUTPUT_COUNTER_NAME => 'pmTotRateGrantedEul_Min',
                  },
                  { START_INDEX => '0',
                    END_INDEX   => '60',
                    REFERENCE_TYPE => 'LAST',
                    REFERENCE_START => '100',
                    REFERENCE_STEP => '+100',
                    OUTPUT_COUNTER_NAME => 'pmTotRateGrantedEul_Max',
                  },
              ],
            },
     	 ],
         pmWaitingTimeEul  => [
            { MANIP_TYPE  => 'WEIGHTED_AVG',
              RANGE_INDEX => [
                  { START_INDEX => '0',
                    END_INDEX   => '28',
                    WEIGHTED_ARRAY => [
		    	5, 15, 25, 35, 45, 55, 65, 75, 
			85, 95, 150, 250, 350, 450, 550, 650, 
			750, 850, 950, 1500, 2500, 3500, 4500, 5500, 
			6500, 7500, 8500, 9500, 10500
		    ],
                    OUTPUT_COUNTER_NAME => 'pmWaitingTimeEul_Avg',
                  },
              ],
            },
            { MANIP_TYPE  => 'REFERENCE',
              RANGE_INDEX => [
                  { START_INDEX => '0',
                    END_INDEX   => '28',
                    REFERENCE_TYPE => 'FIRST',
                    REFERENCE_ARRAY => [
		    	5, 15, 25, 35, 45, 55, 65, 75, 
			85, 95, 150, 250, 350, 450, 550, 650, 
			750, 850, 950, 1500, 2500, 3500, 4500, 5500, 
			6500, 7500, 8500, 9500, 10500
		    ],
                    OUTPUT_COUNTER_NAME => 'pmWaitingTimeEul_Min',
                  },
                  { START_INDEX => '0',
                    END_INDEX   => '28',
                    REFERENCE_TYPE => 'LAST',
                    REFERENCE_ARRAY => [
		    	5, 15, 25, 35, 45, 55, 65, 75, 
			85, 95, 150, 250, 350, 450, 550, 650, 
			750, 850, 950, 1500, 2500, 3500, 4500, 5500, 
			6500, 7500, 8500, 9500, 10500
		    ],
                    OUTPUT_COUNTER_NAME => 'pmWaitingTimeEul_Max',
                  },
              ],
            },
     	 ],
	 # ManagedElement,NodeBFunction,Sector,Carrier,HsDschResources
         pmNoOfHsUsersPerTti  => [
	    { MANIP_TYPE => 'ALL' },
            { MANIP_TYPE  => 'WEIGHTED_AVG',
              RANGE_INDEX => [
                  { START_INDEX => '0',
                    END_INDEX   => '4',
                    WEIGHTED_START => '0',
                    WEIGHTED_STEP => '+1',
                    OUTPUT_COUNTER_NAME => 'pmNoOfHsUsersPerTti_Avg',
                  },
              ],
            },
     	 ],
         pmRemainingResourceCheck  => [
	    { MANIP_TYPE => 'ALL' },
	 ],
         pmSumOfHsScchUsedPwr => [
            { MANIP_TYPE  => 'WEIGHTED_AVG',
              RANGE_INDEX => [
                  { START_INDEX => '0',
                    END_INDEX   => '102',
		    AVG_TYPE => 'dBm',
                    WEIGHTED_ARRAY => [
		    	0, 0.25, 0.75, 1.25, 1.75, 2.25, 2.75, 3.25, 
			3.75, 4.25, 4.75, 5.25, 5.75, 6.25, 6.75, 7.25, 
			7.75, 8.25, 8.75, 9.25, 9.75, 10.25, 10.75, 11.25, 
			11.75, 12.25, 12.75, 13.25, 13.75, 14.25, 14.75, 15.25, 
			15.75, 16.25, 16.75, 17.25, 17.75, 18.25, 18.75, 19.25, 
			19.75, 20.25, 20.75, 21.25, 21.75, 22.25, 22.75, 23.25, 
			23.75, 24.25, 24.75, 25.25, 25.75, 26.25, 26.75, 27.25, 
			27.75, 28.25, 28.75, 29.25, 29.75, 30.25, 30.75, 31.25, 
			31.75, 32.25, 32.75, 33.25, 33.75, 34.25, 34.75, 35.25, 
			35.75, 36.25, 36.75, 37.25, 37.75, 38.25, 38.75, 39.25, 
			39.75, 40.25, 40.75, 41.25, 41.75, 42.25, 42.75, 43.25, 
			43.75, 44.25, 44.75, 45.25, 45.75, 46.25, 46.75, 47.25, 
			47.75, 48.25, 48.75, 49.25, 49.75, 50.25, 50.75
		    ],
                    OUTPUT_COUNTER_NAME => 'pmSumOfHsScchUsedPwr_Avg',
                  },
              ],
            },
            { MANIP_TYPE  => 'REFERENCE',
              RANGE_INDEX => [
                  { START_INDEX => '0',
                    END_INDEX   => '102',
                    REFERENCE_ARRAY => [
		    	0, 0.25, 0.75, 1.25, 1.75, 2.25, 2.75, 3.25, 
			3.75, 4.25, 4.75, 5.25, 5.75, 6.25, 6.75, 7.25, 
			7.75, 8.25, 8.75, 9.25, 9.75, 10.25, 10.75, 11.25, 
			11.75, 12.25, 12.75, 13.25, 13.75, 14.25, 14.75, 15.25, 
			15.75, 16.25, 16.75, 17.25, 17.75, 18.25, 18.75, 19.25, 
			19.75, 20.25, 20.75, 21.25, 21.75, 22.25, 22.75, 23.25, 
			23.75, 24.25, 24.75, 25.25, 25.75, 26.25, 26.75, 27.25, 
			27.75, 28.25, 28.75, 29.25, 29.75, 30.25, 30.75, 31.25, 
			31.75, 32.25, 32.75, 33.25, 33.75, 34.25, 34.75, 35.25, 
			35.75, 36.25, 36.75, 37.25, 37.75, 38.25, 38.75, 39.25, 
			39.75, 40.25, 40.75, 41.25, 41.75, 42.25, 42.75, 43.25, 
			43.75, 44.25, 44.75, 45.25, 45.75, 46.25, 46.75, 47.25, 
			47.75, 48.25, 48.75, 49.25, 49.75, 50.25, 50.75
		    ],
                    REFERENCE_TYPE => 'FIRST',
                    OUTPUT_COUNTER_NAME => 'pmSumOfHsScchUsedPwr_Min',
                  },
                  { START_INDEX => '0',
                    END_INDEX   => '102',
                    REFERENCE_ARRAY => [
		    	0, 0.25, 0.75, 1.25, 1.75, 2.25, 2.75, 3.25, 
			3.75, 4.25, 4.75, 5.25, 5.75, 6.25, 6.75, 7.25, 
			7.75, 8.25, 8.75, 9.25, 9.75, 10.25, 10.75, 11.25, 
			11.75, 12.25, 12.75, 13.25, 13.75, 14.25, 14.75, 15.25, 
			15.75, 16.25, 16.75, 17.25, 17.75, 18.25, 18.75, 19.25, 
			19.75, 20.25, 20.75, 21.25, 21.75, 22.25, 22.75, 23.25, 
			23.75, 24.25, 24.75, 25.25, 25.75, 26.25, 26.75, 27.25, 
			27.75, 28.25, 28.75, 29.25, 29.75, 30.25, 30.75, 31.25, 
			31.75, 32.25, 32.75, 33.25, 33.75, 34.25, 34.75, 35.25, 
			35.75, 36.25, 36.75, 37.25, 37.75, 38.25, 38.75, 39.25, 
			39.75, 40.25, 40.75, 41.25, 41.75, 42.25, 42.75, 43.25, 
			43.75, 44.25, 44.75, 45.25, 45.75, 46.25, 46.75, 47.25, 
			47.75, 48.25, 48.75, 49.25, 49.75, 50.25, 50.75
		    ],
                    REFERENCE_TYPE => 'LAST',
                    OUTPUT_COUNTER_NAME => 'pmSumOfHsScchUsedPwr_Max',
                  },
              ],
            },
         ],
         pmAverageUserRate  => [
            { MANIP_TYPE  => 'WEIGHTED_AVG',
              RANGE_INDEX => [
                  { START_INDEX => '0',
                    END_INDEX   => '17',
                    WEIGHTED_ARRAY => [
		    	4, 12, 24, 40, 56, 80, 112, 160, 
			224, 320, 448, 640, 896, 1280, 1792, 2560, 
			3584, 4608, 
		    ],
                    OUTPUT_COUNTER_NAME => 'pmAverageUserRate_Avg',
                  },
              ],
            },
            { MANIP_TYPE  => 'REFERENCE',
              RANGE_INDEX => [
                  { START_INDEX => '0',
                    END_INDEX   => '17',
                    REFERENCE_TYPE => 'FIRST',
                    REFERENCE_ARRAY => [
		    	4, 12, 24, 40, 56, 80, 112, 160, 
			224, 320, 448, 640, 896, 1280, 1792, 2560, 
			3584, 4608, 
		    ],
                    OUTPUT_COUNTER_NAME => 'pmAverageUserRate_Min',
                  },
                  { START_INDEX => '0',
                    END_INDEX   => '17',
                    REFERENCE_TYPE => 'LAST',
                    REFERENCE_ARRAY => [
		    	4, 12, 24, 40, 56, 80, 112, 160, 
			224, 320, 448, 640, 896, 1280, 1792, 2560, 
			3584, 4608, 
		    ],
                    OUTPUT_COUNTER_NAME => 'pmAverageUserRate_Max',
                  },
              ],
            },
     	 ],
         pmReportedCqi  => [
	    { MANIP_TYPE => 'ALL' },
            { MANIP_TYPE  => 'WEIGHTED_AVG',
              RANGE_INDEX => [
                  { START_INDEX => '1',
                    END_INDEX   => '30',
                    WEIGHTED_START => '1',
                    WEIGHTED_STEP => '+1',
                    OUTPUT_COUNTER_NAME => 'pmReportedCqi_Avg',
                  },
              ],
            },
            { MANIP_TYPE  => 'REFERENCE',
              RANGE_INDEX => [
                  { START_INDEX => '1',
                    END_INDEX   => '30',
                    REFERENCE_TYPE => 'FIRST',
                    REFERENCE_START => '1',
                    REFERENCE_STEP => '+1',
                    OUTPUT_COUNTER_NAME => 'pmReportedCqi_Min',
                  },
                  { START_INDEX => '1',
                    END_INDEX   => '30',
                    REFERENCE_TYPE => 'LAST',
                    REFERENCE_START => '1',
                    REFERENCE_STEP => '+1',
                    OUTPUT_COUNTER_NAME => 'pmReportedCqi_Max',
                  },
              ],
            },
     	 ],
         pmUsedCqi  => [
	    { MANIP_TYPE => 'ALL' },
            { MANIP_TYPE  => 'WEIGHTED_AVG',
              RANGE_INDEX => [
                  { START_INDEX => '0',
                    END_INDEX   => '30',
                    WEIGHTED_START => '0',
                    WEIGHTED_STEP => '+1',
                    OUTPUT_COUNTER_NAME => 'pmUsedCqi_Avg',
                  },
              ],
            },
            { MANIP_TYPE  => 'REFERENCE',
              RANGE_INDEX => [
                  { START_INDEX => '0',
                    END_INDEX   => '30',
                    REFERENCE_TYPE => 'FIRST',
                    REFERENCE_START => '0',
                    REFERENCE_STEP => '+1',
                    OUTPUT_COUNTER_NAME => 'pmUsedCqi_Min',
                  },
                  { START_INDEX => '0',
                    END_INDEX   => '30',
                    REFERENCE_TYPE => 'LAST',
                    REFERENCE_START => '0',
                    REFERENCE_STEP => '+1',
                    OUTPUT_COUNTER_NAME => 'pmUsedCqi_Max',
                  },
              ],
            },
     	 ],
         pmTransmittedCarrierPowerNonHs  => [
            { MANIP_TYPE  => 'WEIGHTED_AVG',
              RANGE_INDEX => [
                  { START_INDEX => '0',
                    END_INDEX   => '51',
		    AVG_TYPE => 'dBm',
                    WEIGHTED_ARRAY => [
		    	25, 25.25, 25.75, 26.25, 26.75, 27.25, 27.75, 28.25, 
			28.75, 29.25, 29.75, 30.25, 30.75, 31.25, 31.75, 32.25, 
			32.75, 33.25, 33.75, 34.25, 34.75, 35.25, 35.75, 36.25, 
			36.75, 37.25, 37.75, 38.25, 38.75, 39.25, 39.75, 40.25, 
			40.75, 41.25, 41.75, 42.25, 42.75, 43.25, 43.75, 44.25, 
			44.75, 45.25, 45.75, 46.25, 46.75, 47.25, 47.75, 48.25, 
			48.75, 49.25, 49.75, 50
		    ],
                    OUTPUT_COUNTER_NAME => 'pmTransmittedCarrierPowerNonHs_Avg',
                  },
              ],
            },
            { MANIP_TYPE  => 'REFERENCE',
              RANGE_INDEX => [
                  { START_INDEX => '0',
                    END_INDEX   => '51',
                    REFERENCE_TYPE => 'FIRST',
                    REFERENCE_ARRAY => [
		    	25, 25.25, 25.75, 26.25, 26.75, 27.25, 27.75, 28.25, 
			28.75, 29.25, 29.75, 30.25, 30.75, 31.25, 31.75, 32.25, 
			32.75, 33.25, 33.75, 34.25, 34.75, 35.25, 35.75, 36.25, 
			36.75, 37.25, 37.75, 38.25, 38.75, 39.25, 39.75, 40.25, 
			40.75, 41.25, 41.75, 42.25, 42.75, 43.25, 43.75, 44.25, 
			44.75, 45.25, 45.75, 46.25, 46.75, 47.25, 47.75, 48.25, 
			48.75, 49.25, 49.75, 50
		    ],
                    OUTPUT_COUNTER_NAME => 'pmTransmittedCarrierPowerNonHs_Min',
                  },
                  { START_INDEX => '0',
                    END_INDEX   => '51',
                    REFERENCE_TYPE => 'LAST',
                    REFERENCE_ARRAY => [
		    	25, 25.25, 25.75, 26.25, 26.75, 27.25, 27.75, 28.25, 
			28.75, 29.25, 29.75, 30.25, 30.75, 31.25, 31.75, 32.25, 
			32.75, 33.25, 33.75, 34.25, 34.75, 35.25, 35.75, 36.25, 
			36.75, 37.25, 37.75, 38.25, 38.75, 39.25, 39.75, 40.25, 
			40.75, 41.25, 41.75, 42.25, 42.75, 43.25, 43.75, 44.25, 
			44.75, 45.25, 45.75, 46.25, 46.75, 47.25, 47.75, 48.25, 
			48.75, 49.25, 49.75, 50
		    ],
                    OUTPUT_COUNTER_NAME => 'pmTransmittedCarrierPowerNonHs_Max',
                  },
              ],
            },
     	 ],
	 # ManagedElement,NodeBFunction,Sector,Carrier,Prach
         pmPropagationDelay  => [
	    { MANIP_TYPE => 'ALL' },
            { MANIP_TYPE  => 'WEIGHTED_AVG',
              RANGE_INDEX => [
                  { START_INDEX => '1',
                    END_INDEX   => '40',
                    WEIGHTED_ARRAY => [
		    	0,0.5, 1.5, 2.5, 3.5, 4.5, 5.5, 6.5, 7.5, 
			8.5, 9.5, 11, 13, 15, 17, 19, 21, 
			23, 25, 27, 29, 31.5, 34.5, 37.5, 40.5, 
			43.5, 46.5, 49.5, 52.5, 55.5, 58.5, 62, 66, 
			70, 74, 78, 82, 86, 90, 94, 98
		    ],
                    OUTPUT_COUNTER_NAME => 'pmPropagationDelay_Avg',
                  },
              ],
            },
            { MANIP_TYPE  => 'REFERENCE',
              RANGE_INDEX => [
                  { START_INDEX => '1',
                    END_INDEX   => '40',
                    REFERENCE_TYPE => 'FIRST',
                    REFERENCE_ARRAY => [
		    	0,0.5, 1.5, 2.5, 3.5, 4.5, 5.5, 6.5, 7.5, 
			8.5, 9.5, 11, 13, 15, 17, 19, 21, 
			23, 25, 27, 29, 31.5, 34.5, 37.5, 40.5, 
			43.5, 46.5, 49.5, 52.5, 55.5, 58.5, 62, 66, 
			70, 74, 78, 82, 86, 90, 94, 98
		    ],
                    OUTPUT_COUNTER_NAME => 'pmPropagationDelay_Min',
                  },
                  { START_INDEX => '1',
                    END_INDEX   => '40',
                    REFERENCE_TYPE => 'LAST',
                    REFERENCE_ARRAY => [
		    	0,0.5, 1.5, 2.5, 3.5, 4.5, 5.5, 6.5, 7.5, 
			8.5, 9.5, 11, 13, 15, 17, 19, 21, 
			23, 25, 27, 29, 31.5, 34.5, 37.5, 40.5, 
			43.5, 46.5, 49.5, 52.5, 55.5, 58.5, 62, 66, 
			70, 74, 78, 82, 86, 90, 94, 98
		    ],
                    OUTPUT_COUNTER_NAME => 'pmPropagationDelay_Max',
                  },
              ],
            },
     	 ],
         pmReceivedPreambleSir  => [
            { MANIP_TYPE  => 'WEIGHTED_AVG',
              RANGE_INDEX => [
                  { START_INDEX => '0',
                    END_INDEX   => '26',
		    AVG_TYPE => 'dB',
                    WEIGHTED_ARRAY => [
		    	-25, -24.5, -23.5, -22.5, -21.5, -20.5, -19.5, -18.5, 
			-17.5, -16.5, -15.5, -14.5, -13.5, -12.5, -11.5, -10.5, 
			-9.5, -8.5, -7.5, -6.5, -5.5, -4.5, -3.5, -2.5, 
			-1.5, -0.5, 0.5
		    ],
                    OUTPUT_COUNTER_NAME => 'pmReceivedPreambleSir_Avg',
                  },
              ],
            },
            { MANIP_TYPE  => 'REFERENCE',
              RANGE_INDEX => [
                  { START_INDEX => '0',
                    END_INDEX   => '26',
                    REFERENCE_TYPE => 'FIRST',
                    REFERENCE_ARRAY => [
		    	-25, -24.5, -23.5, -22.5, -21.5, -20.5, -19.5, -18.5, 
			-17.5, -16.5, -15.5, -14.5, -13.5, -12.5, -11.5, -10.5, 
			-9.5, -8.5, -7.5, -6.5, -5.5, -4.5, -3.5, -2.5, 
			-1.5, -0.5, 0.5
		    ],
                    OUTPUT_COUNTER_NAME => 'pmReceivedPreambleSir_Min',
                  },
                  { START_INDEX => '0',
                    END_INDEX   => '26',
                    REFERENCE_TYPE => 'LAST',
                    REFERENCE_ARRAY => [
		    	-25, -24.5, -23.5, -22.5, -21.5, -20.5, -19.5, -18.5, 
			-17.5, -16.5, -15.5, -14.5, -13.5, -12.5, -11.5, -10.5, 
			-9.5, -8.5, -7.5, -6.5, -5.5, -4.5, -3.5, -2.5, 
			-1.5, -0.5, 0.5
		    ],
                    OUTPUT_COUNTER_NAME => 'pmReceivedPreambleSir_Max',
                  },
              ],
            },
     	 ],
	 # ManagedElement,Equipment,Subrack,UplinkBasebandPool
         pmHwCePoolEul  => [
            { MANIP_TYPE  => 'WEIGHTED_AVG',
              RANGE_INDEX => [
                  { START_INDEX => '0',
                    END_INDEX   => '54',
                    WEIGHTED_ARRAY => [
		    	10, 20, 30, 40, 50, 60, 70, 80, 
			90, 100, 120, 140, 160, 180, 200, 220, 
			240, 260, 280, 300, 320, 340, 360, 380, 
			400, 420, 440, 460, 480, 500, 520, 540, 
			560, 580, 600, 620, 640, 660, 680, 700, 
			720, 740, 760, 780, 800, 820, 840, 860, 
			880, 900, 920, 940, 960, 980, 1000
		    ],
                    OUTPUT_COUNTER_NAME => 'pmHwCePoolEul_Avg',
                  },
              ],
            },
            { MANIP_TYPE  => 'REFERENCE',
              RANGE_INDEX => [
                  { START_INDEX => '0',
                    END_INDEX   => '54',
                    REFERENCE_TYPE => 'FIRST',
                    REFERENCE_ARRAY => [
		    	10, 20, 30, 40, 50, 60, 70, 80, 
			90, 100, 120, 140, 160, 180, 200, 220, 
			240, 260, 280, 300, 320, 340, 360, 380, 
			400, 420, 440, 460, 480, 500, 520, 540, 
			560, 580, 600, 620, 640, 660, 680, 700, 
			720, 740, 760, 780, 800, 820, 840, 860, 
			880, 900, 920, 940, 960, 980, 1000
		    ],
                    OUTPUT_COUNTER_NAME => 'pmHwCePoolEul_Min',
                  },
                  { START_INDEX => '0',
                    END_INDEX   => '54',
                    REFERENCE_TYPE => 'LAST',
                    REFERENCE_ARRAY => [
		    	10, 20, 30, 40, 50, 60, 70, 80, 
			90, 100, 120, 140, 160, 180, 200, 220, 
			240, 260, 280, 300, 320, 340, 360, 380, 
			400, 420, 440, 460, 480, 500, 520, 540, 
			560, 580, 600, 620, 640, 660, 680, 700, 
			720, 740, 760, 780, 800, 820, 840, 860, 
			880, 900, 920, 940, 960, 980, 1000
		    ],
                    OUTPUT_COUNTER_NAME => 'pmHwCePoolEul_Max',
                  },
              ],
            },
     	 ],
	 # ManagedElement,NodeBFunction,Iub,IubDataStreams
         pmEdchIubMeasRate  => [
            { MANIP_TYPE  => 'WEIGHTED_AVG',
              RANGE_INDEX => [
                  { START_INDEX => '0',
                    END_INDEX   => '15',
                    WEIGHTED_ARRAY => [
		    	0.5, 1.5, 3.5, 7.5, 15, 35, 75, 150, 
			350, 750, 1500, 3500, 7500, 15000, 35000, 75000
		    ],
                    OUTPUT_COUNTER_NAME => 'pmEdchIubMeasRate_Avg',
                  },
              ],
            },
            { MANIP_TYPE  => 'REFERENCE',
              RANGE_INDEX => [
                  { START_INDEX => '0',
                    END_INDEX   => '15',
                    REFERENCE_TYPE => 'FIRST',
                    REFERENCE_ARRAY => [
		    	0.5, 1.5, 3.5, 7.5, 15, 35, 75, 150, 
			350, 750, 1500, 3500, 7500, 15000, 35000, 75000
		    ],
                    OUTPUT_COUNTER_NAME => 'pmEdchIubMeasRate_Min',
                  },
                  { START_INDEX => '0',
                    END_INDEX   => '15',
                    REFERENCE_TYPE => 'LAST',
                    REFERENCE_ARRAY => [
		    	0.5, 1.5, 3.5, 7.5, 15, 35, 75, 150, 
			350, 750, 1500, 3500, 7500, 15000, 35000, 75000
		    ],
                    OUTPUT_COUNTER_NAME => 'pmEdchIubMeasRate_Max',
                  },
              ],
            },
     	 ],
         pmIubMacdPduRbsReceivedBits  => [
            { MANIP_TYPE  => 'WEIGHTED_AVG',
              RANGE_INDEX => [
                  { START_INDEX => '0',
                    END_INDEX   => '100',
                    WEIGHTED_START => '200',
                    WEIGHTED_STEP => '+200',
                    OUTPUT_COUNTER_NAME => 'pmIubMacdPduRbsReceivedBits_Avg',
                  },
              ],
            },
            { MANIP_TYPE  => 'REFERENCE',
              RANGE_INDEX => [
                  { START_INDEX => '0',
                    END_INDEX   => '100',
                    REFERENCE_TYPE => 'FIRST',
                    REFERENCE_START => '200',
                    REFERENCE_STEP => '+200',
                    OUTPUT_COUNTER_NAME => 'pmIubMacdPduRbsReceivedBits_Min',
                  },
                  { START_INDEX => '0',
                    END_INDEX   => '100',
                    REFERENCE_TYPE => 'LAST',
                    REFERENCE_START => '200',
                    REFERENCE_STEP => '+200',
                    OUTPUT_COUNTER_NAME => 'pmIubMacdPduRbsReceivedBits_Max',
                  },
              ],
            },
     	 ],
         pmTargetHsRate  => [
            { MANIP_TYPE  => 'WEIGHTED_AVG',
              RANGE_INDEX => [
                  { START_INDEX => '0',
                    END_INDEX   => '100',
                    WEIGHTED_START => '1',
                    WEIGHTED_STEP => '+1',
                    OUTPUT_COUNTER_NAME => 'pmTargetHsRate_Avg',
                  },
              ],
            },
            { MANIP_TYPE  => 'REFERENCE',
              RANGE_INDEX => [
                  { START_INDEX => '0',
                    END_INDEX   => '100',
                    REFERENCE_TYPE => 'FIRST',
                    REFERENCE_START => '1',
                    REFERENCE_STEP => '+1',
                    OUTPUT_COUNTER_NAME => 'pmTargetHsRate_Min',
                  },
                  { START_INDEX => '0',
                    END_INDEX   => '100',
                    REFERENCE_TYPE => 'LAST',
                    REFERENCE_START => '1',
                    REFERENCE_STEP => '+1',
                    OUTPUT_COUNTER_NAME => 'pmTargetHsRate_Max',
                  },
              ],
            },
	    { MANIP_TYPE  => 'TOTAL',
              RANGE_INDEX => [
                   { START_INDEX => '0',
                     END_INDEX   => '70',
                     OUTPUT_COUNTER_NAME => 'pmTargetHsRate_1_70',
                   },
              ],
            },
            { MANIP_TYPE  => 'TOTAL',
              RANGE_INDEX => [
                  { START_INDEX => '0',
                    END_INDEX   => '100',
                    OUTPUT_COUNTER_NAME => 'pmTargetHsRate_1_100',
                  },
              ],
            },

     	 ],
	 # ManagedElement,NodeBFunction,Sector,Carrier
         pmTransmittedCarrierPower  => [
            { MANIP_TYPE  => 'WEIGHTED_AVG',
              RANGE_INDEX => [
                  { START_INDEX => '0',
                    END_INDEX   => '51',
		    AVG_TYPE => 'dBm',
                    WEIGHTED_ARRAY => [
		    	25, 25.25, 25.75, 26.25, 26.75, 27.25, 27.75, 28.25, 
			28.75, 29.25, 29.75, 30.25, 30.75, 31.25, 31.75, 32.25, 
			32.75, 33.25, 33.75, 34.25, 34.75, 35.25, 35.75, 36.25, 
			36.75, 37.25, 37.75, 38.25, 38.75, 39.25, 39.75, 40.25, 
			40.75, 41.25, 41.75, 42.25, 42.75, 43.25, 43.75, 44.25, 
			44.75, 45.25, 45.75, 46.25, 46.75, 47.25, 47.75, 48.25, 
			48.75, 49.25, 49.75, 50
		    ],
                    OUTPUT_COUNTER_NAME => 'pmTransmittedCarrierPower_Avg',
                  },
              ],
            },
            { MANIP_TYPE  => 'REFERENCE',
              RANGE_INDEX => [
                  { START_INDEX => '0',
                    END_INDEX   => '51',
                    REFERENCE_TYPE => 'FIRST',
                    REFERENCE_ARRAY => [
		    	25, 25.25, 25.75, 26.25, 26.75, 27.25, 27.75, 28.25, 
			28.75, 29.25, 29.75, 30.25, 30.75, 31.25, 31.75, 32.25, 
			32.75, 33.25, 33.75, 34.25, 34.75, 35.25, 35.75, 36.25, 
			36.75, 37.25, 37.75, 38.25, 38.75, 39.25, 39.75, 40.25, 
			40.75, 41.25, 41.75, 42.25, 42.75, 43.25, 43.75, 44.25, 
			44.75, 45.25, 45.75, 46.25, 46.75, 47.25, 47.75, 48.25, 
			48.75, 49.25, 49.75, 50
		    ],
                    OUTPUT_COUNTER_NAME => 'pmTransmittedCarrierPower_Min',
                  },
                  { START_INDEX => '0',
                    END_INDEX   => '51',
                    REFERENCE_TYPE => 'LAST',
                    REFERENCE_ARRAY => [
		    	25, 25.25, 25.75, 26.25, 26.75, 27.25, 27.75, 28.25, 
			28.75, 29.25, 29.75, 30.25, 30.75, 31.25, 31.75, 32.25, 
			32.75, 33.25, 33.75, 34.25, 34.75, 35.25, 35.75, 36.25, 
			36.75, 37.25, 37.75, 38.25, 38.75, 39.25, 39.75, 40.25, 
			40.75, 41.25, 41.75, 42.25, 42.75, 43.25, 43.75, 44.25, 
			44.75, 45.25, 45.75, 46.25, 46.75, 47.25, 47.75, 48.25, 
			48.75, 49.25, 49.75, 50
		    ],
                    OUTPUT_COUNTER_NAME => 'pmTransmittedCarrierPower_Max',
                  },
              ],
            },
     	 ],
         pmAverageRssi  => [
            { MANIP_TYPE  => 'WEIGHTED_AVG',
              RANGE_INDEX => [
                  { START_INDEX => '0',
                    END_INDEX   => '64',
		    AVG_TYPE => 'dBm',
                    WEIGHTED_ARRAY => [
		    	-110, -109.75, -109.25, -108.75, -108.25, -107.75, -107.25, -106.75, 
			-106.25, -105.75, -105.25, -104.75, -104.25, -103.75, -103.25, -102.75, 
			-102.25, -101.75, -101.25, -100.75, -100.25, -99.75, -99.25, -98.75, 
			-98.25, -97.75, -97.25, -96.75, -96.25, -95.75, -95.25, -94.75, 
			-94.25, -93.75, -93.25, -92.75, -92.25, -91.75, -91.25, -90.75, 
			-90.25, -89.75, -89.25, -88.75, -88.25, -87.75, -87.25, -86.75, 
			-86.25, -85.75, -85.25, -84.75, -84.25, -83.75, -83.25, -82.75, 
			-82.25, -81.75, -81.25, -80.75, -80.25, -77.5, -72.5, -67.5, 
			-65
		    ],
                    OUTPUT_COUNTER_NAME => 'pmAverageRssi_Avg',
                  },
              ],
            },
            { MANIP_TYPE  => 'REFERENCE',
              RANGE_INDEX => [
                  { START_INDEX => '0',
                    END_INDEX   => '64',
                    REFERENCE_TYPE => 'FIRST',
                    REFERENCE_ARRAY => [
		    	-110, -109.75, -109.25, -108.75, -108.25, -107.75, -107.25, -106.75, 
			-106.25, -105.75, -105.25, -104.75, -104.25, -103.75, -103.25, -102.75, 
			-102.25, -101.75, -101.25, -100.75, -100.25, -99.75, -99.25, -98.75, 
			-98.25, -97.75, -97.25, -96.75, -96.25, -95.75, -95.25, -94.75, 
			-94.25, -93.75, -93.25, -92.75, -92.25, -91.75, -91.25, -90.75, 
			-90.25, -89.75, -89.25, -88.75, -88.25, -87.75, -87.25, -86.75, 
			-86.25, -85.75, -85.25, -84.75, -84.25, -83.75, -83.25, -82.75, 
			-82.25, -81.75, -81.25, -80.75, -80.25, -77.5, -72.5, -67.5, 
			-65
		    ],
                    OUTPUT_COUNTER_NAME => 'pmAverageRssi_Min',
                  },
                  { START_INDEX => '0',
                    END_INDEX   => '64',
                    REFERENCE_TYPE => 'LAST',
                    REFERENCE_ARRAY => [
		    	-110, -109.75, -109.25, -108.75, -108.25, -107.75, -107.25, -106.75, 
			-106.25, -105.75, -105.25, -104.75, -104.25, -103.75, -103.25, -102.75, 
			-102.25, -101.75, -101.25, -100.75, -100.25, -99.75, -99.25, -98.75, 
			-98.25, -97.75, -97.25, -96.75, -96.25, -95.75, -95.25, -94.75, 
			-94.25, -93.75, -93.25, -92.75, -92.25, -91.75, -91.25, -90.75, 
			-90.25, -89.75, -89.25, -88.75, -88.25, -87.75, -87.25, -86.75, 
			-86.25, -85.75, -85.25, -84.75, -84.25, -83.75, -83.25, -82.75, 
			-82.25, -81.75, -81.25, -80.75, -80.25, -77.5, -72.5, -67.5, 
			-65
		    ],
                    OUTPUT_COUNTER_NAME => 'pmAverageRssi_Max',
                  },
              ],
            },
     	 ],
	 # ManagedElement,NodeBFunction,Sector,Carrier,RadioLinks
         pmDpchCodePowerSf4  => [
            { MANIP_TYPE  => 'WEIGHTED_AVG',
              RANGE_INDEX => [
                  { START_INDEX => '0',
                    END_INDEX   => '37',
		    AVG_TYPE => 'dBm',
                    WEIGHTED_ARRAY => [
		    	6, 6.5, 7.5, 8.5, 9.5, 10.5, 11.5, 12.5, 
			13.5, 14.5, 15.5, 16.5, 17.5, 18.5, 19.5, 20.5, 
			21.5, 22.5, 23.5, 24.5, 25.5, 26.5, 27.5, 28.5, 
			29.5, 30.5, 31.5, 32.5, 33.5, 34.5, 35.5, 36.5, 
			37.5, 38.5, 39.5, 40.5, 41.5, 42.5
		    ],
                    OUTPUT_COUNTER_NAME => 'pmDpchCodePowerSf4_Avg',
                  },
              ],
            },
            { MANIP_TYPE  => 'REFERENCE',
              RANGE_INDEX => [
                  { START_INDEX => '0',
                    END_INDEX   => '37',
                    REFERENCE_TYPE => 'FIRST',
                    REFERENCE_ARRAY => [
		    	6, 6.5, 7.5, 8.5, 9.5, 10.5, 11.5, 12.5, 
			13.5, 14.5, 15.5, 16.5, 17.5, 18.5, 19.5, 20.5, 
			21.5, 22.5, 23.5, 24.5, 25.5, 26.5, 27.5, 28.5, 
			29.5, 30.5, 31.5, 32.5, 33.5, 34.5, 35.5, 36.5, 
			37.5, 38.5, 39.5, 40.5, 41.5, 42.5
		    ],
                    OUTPUT_COUNTER_NAME => 'pmDpchCodePowerSf4_Min',
                  },
                  { START_INDEX => '0',
                    END_INDEX   => '37',
                    REFERENCE_TYPE => 'LAST',
                    REFERENCE_ARRAY => [
		    	6, 6.5, 7.5, 8.5, 9.5, 10.5, 11.5, 12.5, 
			13.5, 14.5, 15.5, 16.5, 17.5, 18.5, 19.5, 20.5, 
			21.5, 22.5, 23.5, 24.5, 25.5, 26.5, 27.5, 28.5, 
			29.5, 30.5, 31.5, 32.5, 33.5, 34.5, 35.5, 36.5, 
			37.5, 38.5, 39.5, 40.5, 41.5, 42.5
		    ],
                    OUTPUT_COUNTER_NAME => 'pmDpchCodePowerSf4_Max',
                  },
              ],
            },
     	 ],
         pmDpchCodePowerSf8  => [
            { MANIP_TYPE  => 'WEIGHTED_AVG',
              RANGE_INDEX => [
                  { START_INDEX => '0',
                    END_INDEX   => '37',
		    AVG_TYPE => 'dBm',
                    WEIGHTED_ARRAY => [
		    	6, 6.5, 7.5, 8.5, 9.5, 10.5, 11.5, 12.5, 
			13.5, 14.5, 15.5, 16.5, 17.5, 18.5, 19.5, 20.5, 
			21.5, 22.5, 23.5, 24.5, 25.5, 26.5, 27.5, 28.5, 
			29.5, 30.5, 31.5, 32.5, 33.5, 34.5, 35.5, 36.5, 
			37.5, 38.5, 39.5, 40.5, 41.5, 42.5
		    ],
                    OUTPUT_COUNTER_NAME => 'pmDpchCodePowerSf8_Avg',
                  },
              ],
            },
            { MANIP_TYPE  => 'REFERENCE',
              RANGE_INDEX => [
                  { START_INDEX => '0',
                    END_INDEX   => '37',
                    REFERENCE_TYPE => 'FIRST',
                    REFERENCE_ARRAY => [
		    	6, 6.5, 7.5, 8.5, 9.5, 10.5, 11.5, 12.5, 
			13.5, 14.5, 15.5, 16.5, 17.5, 18.5, 19.5, 20.5, 
			21.5, 22.5, 23.5, 24.5, 25.5, 26.5, 27.5, 28.5, 
			29.5, 30.5, 31.5, 32.5, 33.5, 34.5, 35.5, 36.5, 
			37.5, 38.5, 39.5, 40.5, 41.5, 42.5
		    ],
                    OUTPUT_COUNTER_NAME => 'pmDpchCodePowerSf8_Min',
                  },
                  { START_INDEX => '0',
                    END_INDEX   => '37',
                    REFERENCE_TYPE => 'LAST',
                    REFERENCE_ARRAY => [
		    	6, 6.5, 7.5, 8.5, 9.5, 10.5, 11.5, 12.5, 
			13.5, 14.5, 15.5, 16.5, 17.5, 18.5, 19.5, 20.5, 
			21.5, 22.5, 23.5, 24.5, 25.5, 26.5, 27.5, 28.5, 
			29.5, 30.5, 31.5, 32.5, 33.5, 34.5, 35.5, 36.5, 
			37.5, 38.5, 39.5, 40.5, 41.5, 42.5
		    ],
                    OUTPUT_COUNTER_NAME => 'pmDpchCodePowerSf8_Max',
                  },
              ],
            },
     	 ],
         pmDpchCodePowerSf16  => [
            { MANIP_TYPE  => 'WEIGHTED_AVG',
              RANGE_INDEX => [
                  { START_INDEX => '0',
                    END_INDEX   => '37',
		    AVG_TYPE => 'dBm',
                    WEIGHTED_ARRAY => [
		    	6, 6.5, 7.5, 8.5, 9.5, 10.5, 11.5, 12.5, 
			13.5, 14.5, 15.5, 16.5, 17.5, 18.5, 19.5, 20.5, 
			21.5, 22.5, 23.5, 24.5, 25.5, 26.5, 27.5, 28.5, 
			29.5, 30.5, 31.5, 32.5, 33.5, 34.5, 35.5, 36.5, 
			37.5, 38.5, 39.5, 40.5, 41.5, 42.5
		    ],
                    OUTPUT_COUNTER_NAME => 'pmDpchCodePowerSf16_Avg',
                  },
              ],
            },
            { MANIP_TYPE  => 'REFERENCE',
              RANGE_INDEX => [
                  { START_INDEX => '0',
                    END_INDEX   => '37',
                    REFERENCE_TYPE => 'FIRST',
                    REFERENCE_ARRAY => [
		    	6, 6.5, 7.5, 8.5, 9.5, 10.5, 11.5, 12.5, 
			13.5, 14.5, 15.5, 16.5, 17.5, 18.5, 19.5, 20.5, 
			21.5, 22.5, 23.5, 24.5, 25.5, 26.5, 27.5, 28.5, 
			29.5, 30.5, 31.5, 32.5, 33.5, 34.5, 35.5, 36.5, 
			37.5, 38.5, 39.5, 40.5, 41.5, 42.5
		    ],
                    OUTPUT_COUNTER_NAME => 'pmDpchCodePowerSf16_Min',
                  },
                  { START_INDEX => '0',
                    END_INDEX   => '37',
                    REFERENCE_TYPE => 'LAST',
                    REFERENCE_ARRAY => [
		    	6, 6.5, 7.5, 8.5, 9.5, 10.5, 11.5, 12.5, 
			13.5, 14.5, 15.5, 16.5, 17.5, 18.5, 19.5, 20.5, 
			21.5, 22.5, 23.5, 24.5, 25.5, 26.5, 27.5, 28.5, 
			29.5, 30.5, 31.5, 32.5, 33.5, 34.5, 35.5, 36.5, 
			37.5, 38.5, 39.5, 40.5, 41.5, 42.5
		    ],
                    OUTPUT_COUNTER_NAME => 'pmDpchCodePowerSf16_Max',
                  },
              ],
            },
     	 ],
         pmDpchCodePowerSf32  => [
            { MANIP_TYPE  => 'WEIGHTED_AVG',
              RANGE_INDEX => [
                  { START_INDEX => '0',
                    END_INDEX   => '37',
		    AVG_TYPE => 'dBm',
                    WEIGHTED_ARRAY => [
		    	6, 6.5, 7.5, 8.5, 9.5, 10.5, 11.5, 12.5, 
			13.5, 14.5, 15.5, 16.5, 17.5, 18.5, 19.5, 20.5, 
			21.5, 22.5, 23.5, 24.5, 25.5, 26.5, 27.5, 28.5, 
			29.5, 30.5, 31.5, 32.5, 33.5, 34.5, 35.5, 36.5, 
			37.5, 38.5, 39.5, 40.5, 41.5, 42.5
		    ],
                    OUTPUT_COUNTER_NAME => 'pmDpchCodePowerSf32_Avg',
                  },
              ],
            },
            { MANIP_TYPE  => 'REFERENCE',
              RANGE_INDEX => [
                  { START_INDEX => '0',
                    END_INDEX   => '37',
                    REFERENCE_TYPE => 'FIRST',
                    REFERENCE_ARRAY => [
		    	6, 6.5, 7.5, 8.5, 9.5, 10.5, 11.5, 12.5, 
			13.5, 14.5, 15.5, 16.5, 17.5, 18.5, 19.5, 20.5, 
			21.5, 22.5, 23.5, 24.5, 25.5, 26.5, 27.5, 28.5, 
			29.5, 30.5, 31.5, 32.5, 33.5, 34.5, 35.5, 36.5, 
			37.5, 38.5, 39.5, 40.5, 41.5, 42.5
		    ],
                    OUTPUT_COUNTER_NAME => 'pmDpchCodePowerSf32_Min',
                  },
                  { START_INDEX => '0',
                    END_INDEX   => '37',
                    REFERENCE_TYPE => 'LAST',
                    REFERENCE_ARRAY => [
		    	6, 6.5, 7.5, 8.5, 9.5, 10.5, 11.5, 12.5, 
			13.5, 14.5, 15.5, 16.5, 17.5, 18.5, 19.5, 20.5, 
			21.5, 22.5, 23.5, 24.5, 25.5, 26.5, 27.5, 28.5, 
			29.5, 30.5, 31.5, 32.5, 33.5, 34.5, 35.5, 36.5, 
			37.5, 38.5, 39.5, 40.5, 41.5, 42.5
		    ],
                    OUTPUT_COUNTER_NAME => 'pmDpchCodePowerSf32_Max',
                  },
              ],
            },
     	 ],
         pmDpchCodePowerSf64  => [
            { MANIP_TYPE  => 'WEIGHTED_AVG',
              RANGE_INDEX => [
                  { START_INDEX => '0',
                    END_INDEX   => '37',
		    AVG_TYPE => 'dBm',
                    WEIGHTED_ARRAY => [
		    	6, 6.5, 7.5, 8.5, 9.5, 10.5, 11.5, 12.5, 
			13.5, 14.5, 15.5, 16.5, 17.5, 18.5, 19.5, 20.5, 
			21.5, 22.5, 23.5, 24.5, 25.5, 26.5, 27.5, 28.5, 
			29.5, 30.5, 31.5, 32.5, 33.5, 34.5, 35.5, 36.5, 
			37.5, 38.5, 39.5, 40.5, 41.5, 42.5
		    ],
                    OUTPUT_COUNTER_NAME => 'pmDpchCodePowerSf64_Avg',
                  },
              ],
            },
            { MANIP_TYPE  => 'REFERENCE',
              RANGE_INDEX => [
                  { START_INDEX => '0',
                    END_INDEX   => '37',
                    REFERENCE_TYPE => 'FIRST',
                    REFERENCE_ARRAY => [
		    	6, 6.5, 7.5, 8.5, 9.5, 10.5, 11.5, 12.5, 
			13.5, 14.5, 15.5, 16.5, 17.5, 18.5, 19.5, 20.5, 
			21.5, 22.5, 23.5, 24.5, 25.5, 26.5, 27.5, 28.5, 
			29.5, 30.5, 31.5, 32.5, 33.5, 34.5, 35.5, 36.5, 
			37.5, 38.5, 39.5, 40.5, 41.5, 42.5
		    ],
                    OUTPUT_COUNTER_NAME => 'pmDpchCodePowerSf64_Min',
                  },
                  { START_INDEX => '0',
                    END_INDEX   => '37',
                    REFERENCE_TYPE => 'LAST',
                    REFERENCE_ARRAY => [
		    	6, 6.5, 7.5, 8.5, 9.5, 10.5, 11.5, 12.5, 
			13.5, 14.5, 15.5, 16.5, 17.5, 18.5, 19.5, 20.5, 
			21.5, 22.5, 23.5, 24.5, 25.5, 26.5, 27.5, 28.5, 
			29.5, 30.5, 31.5, 32.5, 33.5, 34.5, 35.5, 36.5, 
			37.5, 38.5, 39.5, 40.5, 41.5, 42.5
		    ],
                    OUTPUT_COUNTER_NAME => 'pmDpchCodePowerSf64_Max',
                  },
              ],
            },
     	 ],
         pmDpchCodePowerSf128  => [
            { MANIP_TYPE  => 'WEIGHTED_AVG',
              RANGE_INDEX => [
                  { START_INDEX => '0',
                    END_INDEX   => '37',
		    AVG_TYPE => 'dBm',
                    WEIGHTED_ARRAY => [
		    	6, 6.5, 7.5, 8.5, 9.5, 10.5, 11.5, 12.5, 
			13.5, 14.5, 15.5, 16.5, 17.5, 18.5, 19.5, 20.5, 
			21.5, 22.5, 23.5, 24.5, 25.5, 26.5, 27.5, 28.5, 
			29.5, 30.5, 31.5, 32.5, 33.5, 34.5, 35.5, 36.5, 
			37.5, 38.5, 39.5, 40.5, 41.5, 42.5
		    ],
                    OUTPUT_COUNTER_NAME => 'pmDpchCodePowerSf128_Avg',
                  },
              ],
            },
            { MANIP_TYPE  => 'REFERENCE',
              RANGE_INDEX => [
                  { START_INDEX => '0',
                    END_INDEX   => '37',
                    REFERENCE_TYPE => 'FIRST',
                    REFERENCE_ARRAY => [
		    	6, 6.5, 7.5, 8.5, 9.5, 10.5, 11.5, 12.5, 
			13.5, 14.5, 15.5, 16.5, 17.5, 18.5, 19.5, 20.5, 
			21.5, 22.5, 23.5, 24.5, 25.5, 26.5, 27.5, 28.5, 
			29.5, 30.5, 31.5, 32.5, 33.5, 34.5, 35.5, 36.5, 
			37.5, 38.5, 39.5, 40.5, 41.5, 42.5
		    ],
                    OUTPUT_COUNTER_NAME => 'pmDpchCodePowerSf128_Min',
                  },
                  { START_INDEX => '0',
                    END_INDEX   => '37',
                    REFERENCE_TYPE => 'LAST',
                    REFERENCE_ARRAY => [
		    	6, 6.5, 7.5, 8.5, 9.5, 10.5, 11.5, 12.5, 
			13.5, 14.5, 15.5, 16.5, 17.5, 18.5, 19.5, 20.5, 
			21.5, 22.5, 23.5, 24.5, 25.5, 26.5, 27.5, 28.5, 
			29.5, 30.5, 31.5, 32.5, 33.5, 34.5, 35.5, 36.5, 
			37.5, 38.5, 39.5, 40.5, 41.5, 42.5
		    ],
                    OUTPUT_COUNTER_NAME => 'pmDpchCodePowerSf128_Max',
                  },
              ],
            },
     	 ],
         pmDpchCodePowerSf256  => [
            { MANIP_TYPE  => 'WEIGHTED_AVG',
              RANGE_INDEX => [
                  { START_INDEX => '0',
                    END_INDEX   => '37',
		    AVG_TYPE => 'dBm',
                    WEIGHTED_ARRAY => [
		    	6, 6.5, 7.5, 8.5, 9.5, 10.5, 11.5, 12.5, 
			13.5, 14.5, 15.5, 16.5, 17.5, 18.5, 19.5, 20.5, 
			21.5, 22.5, 23.5, 24.5, 25.5, 26.5, 27.5, 28.5, 
			29.5, 30.5, 31.5, 32.5, 33.5, 34.5, 35.5, 36.5, 
			37.5, 38.5, 39.5, 40.5, 41.5, 42.5
		    ],
                    OUTPUT_COUNTER_NAME => 'pmDpchCodePowerSf256_Avg',
                  },
              ],
            },
            { MANIP_TYPE  => 'REFERENCE',
              RANGE_INDEX => [
                  { START_INDEX => '0',
                    END_INDEX   => '37',
                    REFERENCE_TYPE => 'FIRST',
                    REFERENCE_ARRAY => [
		    	6, 6.5, 7.5, 8.5, 9.5, 10.5, 11.5, 12.5, 
			13.5, 14.5, 15.5, 16.5, 17.5, 18.5, 19.5, 20.5, 
			21.5, 22.5, 23.5, 24.5, 25.5, 26.5, 27.5, 28.5, 
			29.5, 30.5, 31.5, 32.5, 33.5, 34.5, 35.5, 36.5, 
			37.5, 38.5, 39.5, 40.5, 41.5, 42.5
		    ],
                    OUTPUT_COUNTER_NAME => 'pmDpchCodePowerSf256_Min',
                  },
                  { START_INDEX => '0',
                    END_INDEX   => '37',
                    REFERENCE_TYPE => 'LAST',
                    REFERENCE_ARRAY => [
		    	6, 6.5, 7.5, 8.5, 9.5, 10.5, 11.5, 12.5, 
			13.5, 14.5, 15.5, 16.5, 17.5, 18.5, 19.5, 20.5, 
			21.5, 22.5, 23.5, 24.5, 25.5, 26.5, 27.5, 28.5, 
			29.5, 30.5, 31.5, 32.5, 33.5, 34.5, 35.5, 36.5, 
			37.5, 38.5, 39.5, 40.5, 41.5, 42.5
		    ],
                    OUTPUT_COUNTER_NAME => 'pmDpchCodePowerSf256_Max',
                  },
              ],
            },
     	 ],
         pmAverageSir  => [
            { MANIP_TYPE  => 'WEIGHTED_AVG',
              RANGE_INDEX => [
                  { START_INDEX => '0',
                    END_INDEX   => '37',
		    AVG_TYPE => 'dB',
                    WEIGHTED_ARRAY => [
		    	-7, -6.75, -6.25, -5.75, -5.25, -4.75, -4.25, -3.75, 
			-3.25, -2.75, -2.25, -1.75, -1.25, -0.75, -0.25, 0.25, 
			0.75, 1.25, 1.75, 2.25, 2.75, 3.25, 3.75, 4.25, 
			4.75, 5.25, 5.75, 6.25, 6.75, 7.25, 7.75, 8.25, 
			8.75, 9.25, 9.75, 10.25, 10.75, 11.25
		    ],
                    OUTPUT_COUNTER_NAME => 'pmAverageSir_Avg',
                  },
              ],
            },
            { MANIP_TYPE  => 'REFERENCE',
              RANGE_INDEX => [
                  { START_INDEX => '0',
                    END_INDEX   => '37',
                    REFERENCE_TYPE => 'FIRST',
                    REFERENCE_ARRAY => [
		    	-7, -6.75, -6.25, -5.75, -5.25, -4.75, -4.25, -3.75, 
			-3.25, -2.75, -2.25, -1.75, -1.25, -0.75, -0.25, 0.25, 
			0.75, 1.25, 1.75, 2.25, 2.75, 3.25, 3.75, 4.25, 
			4.75, 5.25, 5.75, 6.25, 6.75, 7.25, 7.75, 8.25, 
			8.75, 9.25, 9.75, 10.25, 10.75, 11.25
		    ],
                    OUTPUT_COUNTER_NAME => 'pmAverageSir_Min',
                  },
                  { START_INDEX => '0',
                    END_INDEX   => '37',
                    REFERENCE_TYPE => 'LAST',
                    REFERENCE_ARRAY => [
		    	-7, -6.75, -6.25, -5.75, -5.25, -4.75, -4.25, -3.75, 
			-3.25, -2.75, -2.25, -1.75, -1.25, -0.75, -0.25, 0.25, 
			0.75, 1.25, 1.75, 2.25, 2.75, 3.25, 3.75, 4.25, 
			4.75, 5.25, 5.75, 6.25, 6.75, 7.25, 7.75, 8.25, 
			8.75, 9.25, 9.75, 10.25, 10.75, 11.25
		    ],
                    OUTPUT_COUNTER_NAME => 'pmAverageSir_Max',
                  },
              ],
            },
     	 ],
         pmAverageSirError  => [
            { MANIP_TYPE  => 'WEIGHTED_AVG',
              RANGE_INDEX => [
                  { START_INDEX => '0',
                    END_INDEX   => '41',
		    AVG_TYPE => 'dB',
                    WEIGHTED_ARRAY => [
		    	-10, -9.75, -9.25, -8.75, -8.25, -7.75, -7.25, -6.75, 
			-6.25, -5.75, -5.25, -4.75, -4.25, -3.75, -3.25, -2.75, 
			-2.25, -1.75, -1.25, -0.75, -0.25, 0.25, 0.75, 1.25, 
			1.75, 2.25, 2.75, 3.25, 3.75, 4.25, 4.75, 5.25, 
			5.75, 6.25, 6.75, 7.25, 7.75, 8.25, 8.75, 9.25, 
			9.75, 10.25
		    ],
                    OUTPUT_COUNTER_NAME => 'pmAverageSirError_Avg',
                  },
              ],
            },
            { MANIP_TYPE  => 'REFERENCE',
              RANGE_INDEX => [
                  { START_INDEX => '0',
                    END_INDEX   => '41',
                    REFERENCE_TYPE => 'FIRST',
                    REFERENCE_ARRAY => [
		    	-10, -9.75, -9.25, -8.75, -8.25, -7.75, -7.25, -6.75, 
			-6.25, -5.75, -5.25, -4.75, -4.25, -3.75, -3.25, -2.75, 
			-2.25, -1.75, -1.25, -0.75, -0.25, 0.25, 0.75, 1.25, 
			1.75, 2.25, 2.75, 3.25, 3.75, 4.25, 4.75, 5.25, 
			5.75, 6.25, 6.75, 7.25, 7.75, 8.25, 8.75, 9.25, 
			9.75, 10.25
		    ],
                    OUTPUT_COUNTER_NAME => 'pmAverageSirError_Min',
                  },
                  { START_INDEX => '0',
                    END_INDEX   => '41',
                    REFERENCE_TYPE => 'LAST',
                    REFERENCE_ARRAY => [
		    	-10, -9.75, -9.25, -8.75, -8.25, -7.75, -7.25, -6.75, 
			-6.25, -5.75, -5.25, -4.75, -4.25, -3.75, -3.25, -2.75, 
			-2.25, -1.75, -1.25, -0.75, -0.25, 0.25, 0.75, 1.25, 
			1.75, 2.25, 2.75, 3.25, 3.75, 4.25, 4.75, 5.25, 
			5.75, 6.25, 6.75, 7.25, 7.75, 8.25, 8.75, 9.25, 
			9.75, 10.25
		    ],
                    OUTPUT_COUNTER_NAME => 'pmAverageSirError_Max',
                  },
              ],
            },
     	 ],
         pmDpcchBer  => [
            { MANIP_TYPE  => 'WEIGHTED_AVG',
              RANGE_INDEX => [
                  { START_INDEX => '0',
                    END_INDEX   => '24',
		    AVG_TYPE => 'LOGARITHM',
                    WEIGHTED_ARRAY => [
		    	0, -2.06375, -2.023125, -1.941875, -1.860625, -1.779375, -1.698125, -1.616875, 
			-1.535625, -1.454375, -1.373125, -1.291875, -1.210625, -1.129375, -1.048125, -0.966875, 
			-0.885625, -0.804375, -0.723125, -0.641875, -0.560625, -0.479375, -0.398125, -0.316875, 
			-0.235625
		    ],
                    OUTPUT_COUNTER_NAME => 'pmDpcchBer_Avg',
                  },
              ],
            },
            { MANIP_TYPE  => 'REFERENCE',
              RANGE_INDEX => [
                  { START_INDEX => '0',
                    END_INDEX   => '24',
                    REFERENCE_TYPE => 'FIRST',
                    REFERENCE_ARRAY => [
		    	0, -2.06375, -2.023125, -1.941875, -1.860625, -1.779375, -1.698125, -1.616875, 
			-1.535625, -1.454375, -1.373125, -1.291875, -1.210625, -1.129375, -1.048125, -0.966875, 
			-0.885625, -0.804375, -0.723125, -0.641875, -0.560625, -0.479375, -0.398125, -0.316875, 
			-0.235625
		    ],
                    OUTPUT_COUNTER_NAME => 'pmDpcchBer_Min',
                  },
                  { START_INDEX => '0',
                    END_INDEX   => '24',
                    REFERENCE_TYPE => 'LAST',
                    REFERENCE_ARRAY => [
		    	0, -2.06375, -2.023125, -1.941875, -1.860625, -1.779375, -1.698125, -1.616875, 
			-1.535625, -1.454375, -1.373125, -1.291875, -1.210625, -1.129375, -1.048125, -0.966875, 
			-0.885625, -0.804375, -0.723125, -0.641875, -0.560625, -0.479375, -0.398125, -0.316875, 
			-0.235625
		    ],
                    OUTPUT_COUNTER_NAME => 'pmDpcchBer_Max',
                  },
              ],
            },
     	 ],
         pmDpdchBer  => [
            { MANIP_TYPE  => 'WEIGHTED_AVG',
              RANGE_INDEX => [
                  { START_INDEX => '0',
                    END_INDEX   => '24',
		    AVG_TYPE => 'LOGARITHM',
                    WEIGHTED_ARRAY => [
		    	0, -2.06375, -2.023125, -1.941875, -1.860625, -1.779375, -1.698125, -1.616875, 
			-1.535625, -1.454375, -1.373125, -1.291875, -1.210625, -1.129375, -1.048125, -0.966875, 
			-0.885625, -0.804375, -0.723125, -0.641875, -0.560625, -0.479375, -0.398125, -0.316875, 
			-0.235625
		    ],
                    OUTPUT_COUNTER_NAME => 'pmDpdchBer_Avg',
                  },
              ],
            },
            { MANIP_TYPE  => 'REFERENCE',
              RANGE_INDEX => [
                  { START_INDEX => '0',
                    END_INDEX   => '24',
                    REFERENCE_TYPE => 'FIRST',
                    REFERENCE_ARRAY => [
		    	0, -2.06375, -2.023125, -1.941875, -1.860625, -1.779375, -1.698125, -1.616875, 
			-1.535625, -1.454375, -1.373125, -1.291875, -1.210625, -1.129375, -1.048125, -0.966875, 
			-0.885625, -0.804375, -0.723125, -0.641875, -0.560625, -0.479375, -0.398125, -0.316875, 
			-0.235625
		    ],
                    OUTPUT_COUNTER_NAME => 'pmDpdchBer_Min',
                  },
                  { START_INDEX => '0',
                    END_INDEX   => '24',
                    REFERENCE_TYPE => 'LAST',
                    REFERENCE_ARRAY => [
		    	0, -2.06375, -2.023125, -1.941875, -1.860625, -1.779375, -1.698125, -1.616875, 
			-1.535625, -1.454375, -1.373125, -1.291875, -1.210625, -1.129375, -1.048125, -0.966875, 
			-0.885625, -0.804375, -0.723125, -0.641875, -0.560625, -0.479375, -0.398125, -0.316875, 
			-0.235625
		    ],
                    OUTPUT_COUNTER_NAME => 'pmDpdchBer_Max',
                  },
              ],
            },
     	 ],
         pmOutOfSynch => [
            { MANIP_TYPE  => 'WEIGHTED_AVG',
              RANGE_INDEX => [
                  { START_INDEX => '0',
                    END_INDEX   => '49',
                    WEIGHTED_START => '200',
                    WEIGHTED_STEP => '+200',
                    OUTPUT_COUNTER_NAME => 'pmOutOfSynch_Avg',
                  },
              ],
            },
            { MANIP_TYPE  => 'REFERENCE',
              RANGE_INDEX => [
                  { START_INDEX => '0',
                    END_INDEX   => '49',
                    REFERENCE_TYPE => 'FIRST',
                    REFERENCE_START => '200',
                    REFERENCE_STEP => '+200',
                    OUTPUT_COUNTER_NAME => 'pmOutOfSynch_Min',
                  },
                  { START_INDEX => '0',
                    END_INDEX   => '49',
                    REFERENCE_TYPE => 'LAST',
                    REFERENCE_START => '200',
                    REFERENCE_STEP => '+200',
                    OUTPUT_COUNTER_NAME => 'pmOutOfSynch_Max',
                  },
              ],
            },
     	 ],
         pmUlSynchTime => [
            { MANIP_TYPE  => 'WEIGHTED_AVG',
              RANGE_INDEX => [
                  { START_INDEX => '0',
                    END_INDEX   => '15',
                    WEIGHTED_ARRAY => [
		    	25, 75, 125, 175, 225, 275, 325, 375, 
			425, 475, 750, 1500, 2500, 3500, 4500, 5500
		    ],
                    OUTPUT_COUNTER_NAME => 'pmUlSynchTime_Avg',
                  },
              ],
            },
            { MANIP_TYPE  => 'REFERENCE',
              RANGE_INDEX => [
                  { START_INDEX => '0',
                    END_INDEX   => '15',
                    REFERENCE_TYPE => 'FIRST',
                    REFERENCE_ARRAY => [
		    	25, 75, 125, 175, 225, 275, 325, 375, 
			425, 475, 750, 1500, 2500, 3500, 4500, 5500
		    ],
                    OUTPUT_COUNTER_NAME => 'pmUlSynchTime_Min',
                  },
                  { START_INDEX => '0',
                    END_INDEX   => '15',
                    REFERENCE_TYPE => 'LAST',
                    REFERENCE_ARRAY => [
		    	25, 75, 125, 175, 225, 275, 325, 375, 
			425, 475, 750, 1500, 2500, 3500, 4500, 5500
		    ],
                    OUTPUT_COUNTER_NAME => 'pmUlSynchTime_Max',
                  },
              ],
            },
     	 ],
         pmUlSynchTimeSHO => [
            { MANIP_TYPE  => 'WEIGHTED_AVG',
              RANGE_INDEX => [
                  { START_INDEX => '0',
                    END_INDEX   => '15',
                    WEIGHTED_ARRAY => [
		    	25, 75, 125, 175, 225, 275, 325, 375, 
			425, 475, 750, 1500, 2500, 3500, 4500, 5500
		    ],
                    OUTPUT_COUNTER_NAME => 'pmUlSynchTimeSHO_Avg',
                  },
              ],
            },
            { MANIP_TYPE  => 'REFERENCE',
              RANGE_INDEX => [
                  { START_INDEX => '0',
                    END_INDEX   => '15',
                    REFERENCE_TYPE => 'FIRST',
                    REFERENCE_ARRAY => [
		    	25, 75, 125, 175, 225, 275, 325, 375, 
			425, 475, 750, 1500, 2500, 3500, 4500, 5500
		    ],
                    OUTPUT_COUNTER_NAME => 'pmUlSynchTimeSHO_Min',
                  },
                  { START_INDEX => '0',
                    END_INDEX   => '15',
                    REFERENCE_TYPE => 'LAST',
                    REFERENCE_ARRAY => [
		    	25, 75, 125, 175, 225, 275, 325, 375, 
			425, 475, 750, 1500, 2500, 3500, 4500, 5500
		    ],
                    OUTPUT_COUNTER_NAME => 'pmUlSynchTimeSHO_Max',
                  },
              ],
            },
     	 ],
         pmNoOfRadioLinksSf4 =>
            [
            {
                  MANIP_TYPE => 'AVERAGE',
		  RANGE_INDEX => 
		  [
		  	{
		  		START_INDEX => '0',
		  		END_INDEX => '14',
		  		OUTPUT_COUNTER_NAME => 'pmNoOfRadioLinksSf4',
		 	},
		  ],
            }
         ],
         pmNoOfRadioLinksSf8 =>
            [
            {
                  MANIP_TYPE => 'AVERAGE',
		  RANGE_INDEX => 
		  [
		  	{
		  		START_INDEX => '0',
		  		END_INDEX => '14',
		  		OUTPUT_COUNTER_NAME => 'pmNoOfRadioLinksSf8',
		 	},
		  ],
            }
         ],
         pmNoOfRadioLinksSf16 =>
            [
            {
                  MANIP_TYPE => 'AVERAGE',
		  RANGE_INDEX => 
		  [
		  	{
		  		START_INDEX => '0',
		  		END_INDEX => '14',
		  		OUTPUT_COUNTER_NAME => 'pmNoOfRadioLinksSf16',
		 	},
		  ],
            }
         ],
         pmNoOfRadioLinksSf32 =>
            [
            {
                  MANIP_TYPE => 'AVERAGE',
		  RANGE_INDEX => 
		  [
		  	{
		  		START_INDEX => '0',
		  		END_INDEX => '14',
		  		OUTPUT_COUNTER_NAME => 'pmNoOfRadioLinksSf32',
		 	},
		  ],
            }
         ],
         pmNoOfRadioLinksSf64 =>
            [
            {
                  MANIP_TYPE => 'AVERAGE',
		  RANGE_INDEX => 
		  [
		  	{
		  		START_INDEX => '0',
		  		END_INDEX => '14',
		  		OUTPUT_COUNTER_NAME => 'pmNoOfRadioLinksSf64',
		 	},
		  ],
            }
         ],
         pmNoOfRadioLinksSf128 =>
            [
            {
                  MANIP_TYPE => 'AVERAGE',
		  RANGE_INDEX => 
		  [
		  	{
		  		START_INDEX => '0',
		  		END_INDEX => '14',
		  		OUTPUT_COUNTER_NAME => 'pmNoOfRadioLinksSf128',
		 	},
		  ],
            }
         ],
         pmNoOfRadioLinksSf256 =>
            [
            {
                  MANIP_TYPE => 'AVERAGE',
		  RANGE_INDEX => 
		  [
		  	{
		  		START_INDEX => '0',
		  		END_INDEX => '14',
		  		OUTPUT_COUNTER_NAME => 'pmNoOfRadioLinksSf256',
		 	},
		  ],
            }
         ],
 
     }, # end of counters to manip
); # end of DDM manip rules

sub ddm_manip_config {
   return \%DDM_MANIP_RULES;
}

1;
